@@ -1,8 +1,13 @@
 package RPC::ExtDirect::Test::Bar;
 
+use strict;
+use warnings;
+no  warnings 'uninitialized';
+
 use base 'RPC::ExtDirect::Test::Foo';
 
-use RPC::ExtDirect;
+# Define package scope hooks
+use RPC::ExtDirect BEFORE => \&bar_before, after => \&bar_after;
 
 use Carp;
 
@@ -10,12 +15,14 @@ use Carp;
 sub bar_foo : ExtDirect(4) { croak 'bar foo!' }
 
 # Return number of passed arguments
-sub bar_bar : ExtDirect(5) { shift; return scalar @_; }
+sub bar_bar : ExtDirect(5) { shift; pop; return scalar @_; }
 
 # This is a form handler
 sub bar_baz : ExtDirect( formHandler ) {
     my ($class, %param) = @_;
 
+    delete $param{_env};
+
     # Simulate uploaded file handling
     my $uploads = $param{file_uploads};
     return \%param unless $uploads;
@@ -36,4 +43,11 @@ sub bar_baz : ExtDirect( formHandler ) {
     return \%param;
 }
 
+sub bar_before {
+    return 1;
+}
+
+sub bar_after {
+}
+
 1;
